==> nextcloud-app-mail-3.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Surel",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Password required" : "Kata sandi diperlukan",
    "Signature" : "Tanda",
    "Go back" : "Kembali",
    "Email address" : "Alamat surel",
    "Cancel" : "Membatalkan",
    "List" : "Daftar",
    "Add mail account" : "Tambahkan akun surel",
    "Register" : "Daftar",
    "Archive" : "Arsip",
    "Delete" : "Hapus",
    "Search" : "Cari",
    "Send" : "Kirim",
    "Refresh" : "Segarkan",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Choose" : "Pilih",
    "Confirm" : "Konfirmasi",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Unselect" : "Batal pilih",
    "Select" : "Pilih",
    "Edit tags" : "Sunting label",
    "Back" : "Kembali",
    "Create event" : "Buat acara",
    "Forward" : "Teruskan",
    "All day" : "Sepanjang hari",
    "Description" : "Deskrisi",
    "Create" : "Buat",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Other" : "Lainnya",
    "Reply" : "Balas",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Move" : "Pindah",
    "Quota" : "Kuota",
    "Saving" : "Menyimpan",
    "Remove account" : "Hapus akun",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Edit name" : "Edit nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Retry" : "Ulangi",
    "Sending …" : "Mengirim ...",
    "Draft" : "Draf",
    "Message" : "Pesan",
    "Copy to clipboard" : "Salin ke papan klip",
    "Add" : "Masukkan",
    "Close" : "Tutup",
    "Date" : "Date",
    "Tags" : "Tag",
    "Clear" : "Bersihkan",
    "Disabled" : "Dinonaktifkan",
    "Enabled" : "Diaktifkan",
    "Add tag" : "Tambahkan tag",
    "Tag already exists" : "Tag sudah ada",
    "Unsubscribe" : "Berhenti berlangganan",
    "Mark as unread" : "Tandai belum dibaca",
    "Mark as read" : "tandai sudah dibaca",
    "Remove" : "Buang",
    "(organizer)" : "(penyelenggara)",
    "Untitled event" : "Acara tanpa judul",
    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "General" : "Umum",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Berlaku sampai",
    "Certificate" : "Sertifikat",
    "Account connected" : "Akun terhubung",
    "Connect your mail account" : "Hubungkan akun surel Anda",
    "All" : "Semua",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-4.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Surel",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Password required" : "Kata sandi diperlukan",
    "Signature" : "Tanda",
    "Go back" : "Kembali",
    "Email address" : "Alamat surel",
    "Cancel" : "Membatalkan",
    "Add mail account" : "Tambahkan akun surel",
    "General" : "Umum",
    "List" : "Daftar",
    "Register" : "Daftar",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Archive" : "Arsip",
    "Delete" : "Hapus",
    "Search" : "Cari",
    "Send" : "Kirim",
    "Refresh" : "Segarkan",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Choose" : "Pilih",
    "Confirm" : "Konfirmasi",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Unselect" : "Batal pilih",
    "Select" : "Pilih",
    "Edit tags" : "Sunting label",
    "Back" : "Kembali",
    "Create event" : "Buat acara",
    "Forward" : "Teruskan",
    "All day" : "Sepanjang hari",
    "Description" : "Deskrisi",
    "Create" : "Buat",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Remove" : "Buang",
    "email" : "surel",
    "Other" : "Lainnya",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Move" : "Pindah",
    "Quota" : "Kuota",
    "Saving" : "Menyimpan",
    "Remove account" : "Hapus akun",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Rename" : "Ubah nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Retry" : "Ulangi",
    "Sending …" : "Mengirim ...",
    "Draft" : "Draf",
    "Reply" : "Balas",
    "Message" : "Pesan",
    "Copy to clipboard" : "Salin ke papan klip",
    "Add" : "Masukkan",
    "Close" : "Tutup",
    "Date" : "Date",
    "Tags" : "Tag",
    "Clear" : "Bersihkan",
    "Add tag" : "Tambahkan tag",
    "Tag already exists" : "Tag sudah ada",
    "Unsubscribe" : "Berhenti berlangganan",
    "Mark as unread" : "Tandai belum dibaca",
    "Mark as read" : "tandai sudah dibaca",
    "(organizer)" : "(penyelenggara)",
    "Untitled event" : "Acara tanpa judul",
    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Berlaku sampai",
    "Certificate" : "Sertifikat",
    "Account connected" : "Akun terhubung",
    "Connect your mail account" : "Hubungkan akun surel Anda",
    "All" : "Semua",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s"
},
"nplurals=1; plural=0;");
